@@ -82,12 +82,9 @@ class JSONParser:
             self.config[node_id].get("volume (cubic meters)"), "m3"
         )
 
-        min, max, avg = self.parse_flow_or_gen_capacity(
-            self.config[node_id].get("flowrate (MGD)")
+        min_flow, max_flow, avg_flow = self.parse_min_max_avg(
+            self.config[node_id].get("flowrate (MGD)"), "MGD"
         )
-        min_flow = utils.parse_quantity(min, "MGD")
-        max_flow = utils.parse_quantity(max, "MGD")
-        avg_flow = utils.parse_quantity(avg, "MGD")
 
         # create correct type of node class
         if self.config[node_id]["type"] == "Network":
@@ -185,15 +182,20 @@ class JSONParser:
                 tags={},
             )
         elif self.config[node_id]["type"] == "Cogeneration":
-            min, max, avg = self.parse_flow_or_gen_capacity(
-                self.config[node_id].get("generation_capacity (kW)")
+            min, max, avg = self.parse_min_max_avg(
+                self.config[node_id].get("generation_capacity (kW)"), "kW"
             )
-            min = utils.parse_quantity(min, "kW")
-            max = utils.parse_quantity(max, "kW")
-            avg = utils.parse_quantity(avg, "kW")
             node_obj = node.Cogeneration(
                 node_id, input_contents, min, max, avg, num_units, tags={}
             )
+            # TODO: support non-constant efficiency curve
+            efficiency = self.config[node_id].get("efficiency")
+            if efficiency:
+
+                def efficiency_curve(arg):
+                    return float(efficiency)
+
+                node_obj.set_energy_efficiency(efficiency_curve)
         elif self.config[node_id]["type"] == "Digestion":
             digester_type = self.config[node_id].get("digester_type")
             node_obj = node.Digestion(
@@ -319,12 +321,15 @@ class JSONParser:
         if entry_point:
             entry_point = destination.get_node(entry_point)
 
-        min_flow, max_flow, avg_flow = self.parse_flow_or_gen_capacity(
-            self.config[connection_id].get("flowrate (MGD)")
+        min_flow, max_flow, avg_flow = self.parse_min_max_avg(
+            self.config[connection_id].get("flowrate (MGD)"), "MGD"
+        )
+        min_pres, max_pres, avg_pres = self.parse_min_max_avg(
+            self.config[connection_id].get("pressure (PSI)"), "PSI"
+        )
+        lower, higher = self.parse_heating_values(
+            self.config[connection_id].get("heating_values (BTU/scf)"), "BTU/scf"
         )
-        min_flow = utils.parse_quantity(min_flow, "MGD")
-        max_flow = utils.parse_quantity(max_flow, "MGD")
-        avg_flow = utils.parse_quantity(avg_flow, "MGD")
 
         if self.config[connection_id]["type"] == "Pipe":
             diameter = utils.parse_quantity(
@@ -338,7 +343,9 @@ class JSONParser:
                 min_flow,
                 max_flow,
                 avg_flow,
-                diameter,
+                diameter=diameter,
+                lower_heating_value=lower,
+                higher_heating_value=higher,
                 tags={},
                 bidirectional=bidirectional,
                 exit_point=exit_point,
@@ -511,24 +518,62 @@ class JSONParser:
         return contents
 
     @staticmethod
-    def parse_flow_or_gen_capacity(flow_or_gen):
+    def parse_min_max_avg(min_max_avg, units=None):
         """Converts a dictionary into a tuple of flow rates
 
         Parameters
         ----------
-        flowrate : dict
+        min_max_avg : dict
             dictionary of the form {'min': int, 'max': int, 'avg': int}
 
+        units : str
+            units to be parsed into a Pint Quantity
+
         Returns
         -------
-        (int, int, int)
-            min, max, and average flow rate as a tuple
+        (Quantity, Quantity, Quantity) or (float, float, float)
+            (min, max, and average) with the given Pint units as a tuple.
+            If no units given, then returns a tuple of floats.
         """
-        if flow_or_gen is None:
+        if min_max_avg is None:
             return (None, None, None)
         else:
-            return (
-                flow_or_gen.get("min"),
-                flow_or_gen.get("max"),
-                flow_or_gen.get("avg"),
-            )
+            if units:
+                return (
+                    utils.parse_quantity(min_max_avg.get("min"), units),
+                    utils.parse_quantity(min_max_avg.get("max"), units),
+                    utils.parse_quantity(min_max_avg.get("avg"), units),
+                )
+            else:
+                return (
+                    min_max_avg.get("min"),
+                    min_max_avg.get("max"),
+                    min_max_avg.get("avg"),
+                )
+
+    @staticmethod
+    def parse_heating_values(heating_vals, units=None):
+        """Converts a dictionary into a tuple of flow rates
+
+        Parameters
+        ----------
+        heating_vals : dict
+            dictionary of the form {'lower': float, 'higher': float}
+
+        Returns
+        -------
+        (Quantity, Quantity) or (float, float)
+            (lower, higher) heating values as a tuple, with units applied.
+            Given as a float if no units are specified
+
+        """
+        if heating_vals is None:
+            return (None, None)
+        else:
+            if units:
+                return (
+                    utils.parse_quantity(heating_vals.get("lower"), units),
+                    utils.parse_quantity(heating_vals.get("higher"), units),
+                )
+            else:
+                return (heating_vals.get("lower"), heating_vals.get("higher"))
